@@ -38,7 +38,14 @@ def remove_unneeded_f_strings(
 def visit_file(file: Path) -> bool:
     contents = file.read_text()
     visitor = JoinedStrVisitor()
-    visitor.visit(ast.parse(contents))
+
+    try:
+        parsed = ast.parse(contents)
+    except SyntaxError:
+        print(f'Skipping {str(file)} due to its syntax errors')
+        return False
+
+    visitor.visit(parsed)
 
     if not visitor.unneeded_f_strings:
         return False
@@ -51,21 +58,23 @@ def visit_file(file: Path) -> bool:
         return True
 
 
-def visit_path(file_or_dir: str) -> None:
+def visit_path(file_or_dir: str) -> int:
+    ret = 0
     path = Path(file_or_dir)
     if path.is_dir():
         for p in path.glob('**/*.py'):
-            visit_file(p)
+            ret += int(visit_file(p))
     else:
-        visit_file(path)
+        ret += int(visit_file(path))
+    return ret
 
 
-def main() -> None:
+def main() -> int:
     parser = argparse.ArgumentParser()
     parser.add_argument('file_or_dir')
     args = parser.parse_args()
 
-    visit_path(args.file_or_dir)
+    return visit_path(args.file_or_dir)
 
 
 if __name__ == '__main__':
